<?php

namespace Intergo\OptOut\Repositories;

use Intergo\OptOut\Enums\ContactsEnum;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\DB;

class ContactRepository
{
    protected DB $db;

    public function __construct(DB $db)
    {
        $this->db = $db;
    }

    /**
     * @param $appUserId
     * @return Collection
     */
    public function getOptOutsByUserId($appUserId)
    {
        return $this->db::connection(ContactsEnum::DB_CONNECTION)->table(ContactsEnum::CONTACTS_TABLE)
            ->where('is_optout', 1)
            ->where('user_id', $appUserId)
            ->get('phone');
    }

    /**
     * @param array $listIds
     * @return Collection
     */
    public function getOptOutsByListIds(array $listIds)
    {
        return $this->db::connection(ContactsEnum::DB_CONNECTION)->table(ContactsEnum::CONTACTS_TABLE)
            ->leftJoin('list_contacts', 'contacts.id', '=', 'list_contacts.contact_id')
            ->leftJoin('user_lists', function ($join) {
                $join->on('user_lists.id', '=', 'list_contacts.user_list_id');
                $join->on('user_lists.user_id', '=', 'contacts.user_id');
            })
            ->whereIn('user_lists.id', $listIds)
            ->groupBy('contacts.phone')
            ->having('contact_optout', true)
            ->get([
                'contacts.phone',
                DB::raw(
                    'CASE WHEN contacts.is_optout THEN contacts.is_optout ELSE min(list_contacts.is_optout) END as contact_optout'
                )
            ]);
    }
}
